@@ -83,9 +83,13 @@ class Wsdl(WsdlBase):
                                 normal=('cl_autopartition_set',),
                                 hide=('cl_autopartition_set',
                                       'cl_autopartition_root_size',
+                                      'cl_autopartition_root_format',
+                                      'cl_autopartition_calculate_format',
                                       'cl_autopartition_swap_size',),
                                 brief=('cl_autopartition_brief_set',),
                                 expert=('cl_autopartition_scheme',
+                                        'cl_autopartition_root_format',
+                                        'cl_autopartition_calculate_format',
                                         'cl_autopartition_table',
                                         'cl_autopartition_root_size',
                                         'cl_autopartition_swap_size',
